@@ -23,6 +23,7 @@
 #include <QStringList>
 #include <QSet>
 #include <QColor>
+#include <QVariant>
 
 #include "analitzaplotexport.h"
 #include "plottingenums.h"
@@ -67,7 +68,7 @@ public:
 
     void clearTags();
     void addTags(const QSet<QString>& tag);
-	QSet<QString> tags() const;
+    QSet<QString> tags() const;
 
 protected:
     void setModel(PlotsModel *m);
@@ -84,4 +85,6 @@ private:
 
 }
 
+Q_DECLARE_METATYPE(Analitza::PlotItem*);
+
 #endif // ANALITZAPLOT_PLOTITEM_H
